@@ -10,11 +10,11 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-'''
+"""
 Interface for database access.
 
 SQLAlchemy is currently the only supported backend.
-'''
+"""
 
 from oslo_config import cfg
 from oslo_db import api
@@ -129,6 +129,10 @@ def cluster_lock_acquire(cluster_id, action_id, scope):
     return IMPL.cluster_lock_acquire(cluster_id, action_id, scope)
 
 
+def cluster_is_locked(cluster_id):
+    return IMPL.cluster_is_locked(cluster_id)
+
+
 def cluster_lock_release(cluster_id, action_id, scope):
     return IMPL.cluster_lock_release(cluster_id, action_id, scope)
 
@@ -141,6 +145,10 @@ def node_lock_acquire(node_id, action_id):
     return IMPL.node_lock_acquire(node_id, action_id)
 
 
+def node_is_locked(node_id):
+    return IMPL.node_is_locked(node_id)
+
+
 def node_lock_release(node_id, action_id):
     return IMPL.node_lock_release(node_id, action_id)
 
@@ -321,6 +329,11 @@ def action_get(context, action_id, project_safe=True, refresh=False):
                            refresh=refresh)
 
 
+def action_list_active_scaling(context, cluster_id, project_safe=True):
+    return IMPL.action_list_active_scaling(context, cluster_id,
+                                           project_safe=project_safe)
+
+
 def action_get_by_name(context, name, project_safe=True):
     return IMPL.action_get_by_name(context, name, project_safe=project_safe)
 
@@ -334,6 +347,11 @@ def action_get_all_by_owner(context, owner):
     return IMPL.action_get_all_by_owner(context, owner)
 
 
+def action_get_all_active_by_target(context, target_id, project_safe=True):
+    return IMPL.action_get_all_active_by_target(context, target_id,
+                                                project_safe=project_safe)
+
+
 def action_get_all(context, filters=None, limit=None, marker=None, sort=None,
                    project_safe=True):
     return IMPL.action_get_all(context, filters=filters, sort=sort,
@@ -397,17 +415,17 @@ def action_abandon(context, action_id, values=None):
 
 
 def action_lock_check(context, action_id, owner=None):
-    '''Check whether an action has been locked(by a owner).'''
+    """Check whether an action has been locked(by an owner)."""
     return IMPL.action_lock_check(context, action_id, owner)
 
 
 def action_signal(context, action_id, value):
-    '''Send signal to an action via DB.'''
+    """Send signal to an action via DB."""
     return IMPL.action_signal(context, action_id, value)
 
 
 def action_signal_query(context, action_id):
-    '''Query signal status for the specified action.'''
+    """Query signal status for the specified action."""
     return IMPL.action_signal_query(context, action_id)
 
 
@@ -468,6 +486,10 @@ def service_get_all():
     return IMPL.service_get_all()
 
 
+def service_get_all_expired(binary):
+    return IMPL.service_get_all_expired(binary)
+
+
 def gc_by_engine(engine_id):
     return IMPL.gc_by_engine(engine_id)
 
@@ -498,16 +520,25 @@ def registry_get_by_param(context, params):
     return IMPL.registry_get_by_param(context, params)
 
 
-def db_sync(engine, version=None):
-    """Migrate the database to `version` or the most recent version."""
-    return IMPL.db_sync(engine, version=version)
+def registry_list_ids_by_service(context, params):
+    return IMPL.registry_list_by_service(context, params)
 
 
-def db_version(engine):
+def db_sync(db_url=None):
+    """Migrate the database to the most recent version."""
+    return IMPL.db_sync(db_url)
+
+
+def db_version():
     """Display the current database version."""
-    return IMPL.db_version(engine)
+    return IMPL.db_version()
 
 
 def event_purge(engine, project, granularity, age):
     """Purge the event records in database."""
     return IMPL.event_purge(project, granularity, age)
+
+
+def action_purge(engine, project, granularity, age):
+    """Purge the action records in database."""
+    return IMPL.action_purge(project, granularity, age)
