@@ -18,7 +18,6 @@ from oslo_utils import uuidutils
 from senlin.common import consts
 from senlin.common import context as senlin_context
 from senlin.common import exception
-from senlin.common.i18n import _
 from senlin.common import utils
 from senlin.drivers import base as driver_base
 from senlin.objects import credential as co
@@ -218,8 +217,7 @@ class Receiver(object):
         try:
             base = kc.get_senlin_endpoint()
         except exception.InternalError as ex:
-            msg = _('Senlin endpoint can not be found: %s.') % ex.message
-            LOG.warning(msg)
+            LOG.warning('Senlin endpoint can not be found: %s.', ex)
 
         return base
 
@@ -236,7 +234,10 @@ class Receiver(object):
             'username': service_creds.get('username'),
             'password': service_creds.get('password'),
             'auth_url': service_creds.get('auth_url'),
-            'user_domain_name': service_creds.get('user_domain_name')
+            'user_domain_name': service_creds.get('user_domain_name'),
+            'project_domain_name': service_creds.get('project_domain_name'),
+            'verify': service_creds.get('verify'),
+            'interface': service_creds.get('interface'),
         }
 
         cred = co.Credential.get(oslo_context.get_current(), user, project)
