@@ -32,9 +32,16 @@ LOG = logging.getLogger(__name__)
 class ServerProfile(base.Profile):
     """Profile for an OpenStack Nova server."""
 
+    VERSION = '1.2'
     VERSIONS = {
         '1.0': [
             {'status': consts.SUPPORTED, 'since': '2016.04'}
+        ],
+        '1.1': [
+            {'status': consts.SUPPORTED, 'since': '2023.04'}
+        ],
+        '1.2': [
+            {'status': consts.SUPPORTED, 'since': '2023.07'}
         ]
     }
 
@@ -56,19 +63,19 @@ class ServerProfile(base.Profile):
         BDM2_UUID, BDM2_SOURCE_TYPE, BDM2_DESTINATION_TYPE,
         BDM2_DISK_BUS, BDM2_DEVICE_NAME, BDM2_VOLUME_SIZE,
         BDM2_GUEST_FORMAT, BDM2_BOOT_INDEX, BDM2_DEVICE_TYPE,
-        BDM2_DELETE_ON_TERMINATION,
+        BDM2_DELETE_ON_TERMINATION, BDM2_VOLUME_TYPE,
     ) = (
         'uuid', 'source_type', 'destination_type', 'disk_bus',
         'device_name', 'volume_size', 'guest_format', 'boot_index',
-        'device_type', 'delete_on_termination',
+        'device_type', 'delete_on_termination', 'volume_type'
     )
 
     NETWORK_KEYS = (
         PORT, VNIC_TYPE, FIXED_IP, NETWORK, PORT_SECURITY_GROUPS,
-        FLOATING_NETWORK, FLOATING_IP,
+        FLOATING_NETWORK, FLOATING_IP, SUBNET
     ) = (
         'port', 'vnic_type', 'fixed_ip', 'network', 'security_groups',
-        'floating_network', 'floating_ip',
+        'floating_network', 'floating_ip', 'subnet'
     )
 
     PERSONALITY_KEYS = (
@@ -142,6 +149,9 @@ class ServerProfile(base.Profile):
                         _('Whether to delete the volume when the server '
                           'stops.'),
                     ),
+                    BDM2_VOLUME_TYPE: schema.String(
+                        _('Id or name of volume type.'),
+                    ),
                 }
             ),
         ),
@@ -203,6 +213,10 @@ class ServerProfile(base.Profile):
                         _('The floating IP address to be associated with '
                           'this port.'),
                     ),
+                    SUBNET: schema.String(
+                        _('Subnet in which to allocate the IP address for '
+                          'this port.'),
+                    ),
                 },
             ),
             updatable=True,
@@ -440,6 +454,23 @@ class ServerProfile(base.Profile):
             else:
                 raise
 
+    def _validate_volume_type(self, obj, name_or_id, reason=None):
+        try:
+            return self.block_storage(obj).volume_type_get(name_or_id, False)
+        except exc.InternalError as ex:
+            if reason == 'create':
+                raise exc.EResourceCreation(type='server',
+                                            message=str(ex))
+            elif reason == 'update':
+                raise exc.EResourceUpdate(type='server', id=obj.physical_id,
+                                          message=str(ex))
+            elif ex.code == 404:
+                msg = _("The specified volume type '%(k)s' could not be found."
+                        ) % {'k': name_or_id}
+                raise exc.InvalidSpec(message=msg)
+            else:
+                raise
+
     def do_validate(self, obj):
         """Validate if the spec has provided valid info for server creation.
 
@@ -476,6 +507,9 @@ class ServerProfile(base.Profile):
             for key in self.BDM2_KEYS:
                 if bd[key] is None:
                     del bd[key]
+            if 'volume_type' in bd:
+                bd['volume_type'] = self._validate_volume_type(
+                    bd['volume_type'])
             if 'uuid' in bd and 'source_type' in bd:
                 if bd['source_type'] == 'image':
                     self._validate_image(obj, bd['uuid'], reason)
@@ -531,6 +565,25 @@ class ServerProfile(base.Profile):
         except exc.InternalError as ex:
             return str(ex)
 
+    def _check_subnet(self, nc, subnet, result):
+        """Check the specified subnet.
+
+        :param nc: network driver connection.
+        :param subnet: the name or ID of subnet to check.
+        :param result: the result that is used as return value.
+        :returns: None if succeeded or an error message if things go wrong.
+        """
+        if subnet is None:
+            return
+        try:
+            net_obj = nc.subnet_get(subnet)
+            if net_obj is None:
+                return _("The specified subnet %s could not be found."
+                         ) % subnet
+            result[self.SUBNET] = net_obj.id
+        except exc.InternalError as ex:
+            return str(ex)
+
     def _check_port(self, nc, port, result):
         """Check the specified port.
 
@@ -614,6 +667,11 @@ class ServerProfile(base.Profile):
         error = self._check_network(nc, net, result)
         _verify(error)
 
+        # check subnet
+        subnet_net = net_spec.get(self.SUBNET)
+        error = self._check_subnet(nc, subnet_net, result)
+        _verify(error)
+
         # check port
         port = net_spec.get(self.PORT)
         error = self._check_port(nc, port, result)
@@ -667,9 +725,15 @@ class ServerProfile(base.Profile):
         port_attr = {
             'network_id': net_spec.get(self.NETWORK),
         }
+        fixed_ips = {}
         fixed_ip = net_spec.get(self.FIXED_IP, None)
         if fixed_ip:
-            port_attr['fixed_ips'] = [fixed_ip]
+            fixed_ips['fixed_ip'] = fixed_ip
+        subnet = net_spec.get(self.SUBNET, None)
+        if subnet:
+            fixed_ips['subnet_id'] = subnet
+        if fixed_ips:
+            port_attr['fixed_ips'] = [fixed_ips]
         security_groups = net_spec.get(self.PORT_SECURITY_GROUPS, [])
         if security_groups:
             port_attr['security_groups'] = security_groups
@@ -1414,7 +1478,8 @@ class ServerProfile(base.Profile):
                                 self._nw_compare(n, nw, 'port') and
                                 self._nw_compare(n, nw, 'fixed_ip') and
                                 self._nw_compare(n, nw, 'floating_network') and
-                                self._nw_compare(n, nw, 'floating_ip'))]
+                                self._nw_compare(n, nw, 'floating_ip') and
+                                self._nw_compare(n, nw, 'subnet'))]
             for n in sg_create_nw:
                 # don't create networks with only security group changes
                 LOG.debug("Network %s only has security group changes, "
@@ -1599,11 +1664,8 @@ class ServerProfile(base.Profile):
         :return: The flavor_id for the server.
         """
         flavor = server['flavor']
-
-        if 'id' in flavor:
-            return flavor['id']
-
-        return self.compute(obj).flavor_find(flavor['original_name'], False).id
+        flavor_name = flavor.get('name') or flavor.get('original_name')
+        return self.compute(obj).flavor_find(flavor_name, False).id
 
     def _get_image_id(self, obj, server, op):
         """Get image id.
